@@ -1,6 +1,6 @@
 from .....core import BaseAnalyzer, Validator, Required
 from .....config.consts import CONFIG_FORMAT, CONFIG_SHEET, CONFIG_FORCE_STRINGS,\
-    CONFIG_SHEET_NAMES, CONFIG_WORKBOOK_CACHE
+    CONFIG_SHEET_NAMES, CONFIG_WORKBOOK_CACHE, CONFIG_FILL_MERGED_CELLS
 
 
 class XLSFormatAnalyzer(BaseAnalyzer):
@@ -13,6 +13,7 @@ class XLSFormatAnalyzer(BaseAnalyzer):
         if self.config[CONFIG_FORMAT] == 'xls':
             self.config[CONFIG_FORCE_STRINGS] = True
             self.config[CONFIG_WORKBOOK_CACHE] = {}
+            self.config[CONFIG_FILL_MERGED_CELLS] = True
             self.config[CONFIG_SHEET_NAMES] = [
                 (i+1, name)
                 for i, name in
@@ -21,6 +22,7 @@ class XLSFormatAnalyzer(BaseAnalyzer):
         elif self.config[CONFIG_FORMAT] == 'xlsx':
             self.config[CONFIG_FORCE_STRINGS] = True
             self.config[CONFIG_WORKBOOK_CACHE] = {}
+            self.config[CONFIG_FILL_MERGED_CELLS] = True
             self.config[CONFIG_SHEET_NAMES] = [
                 (i, name)
                 for i, name in
