@@ -1,6 +1,7 @@
 from dataflows import Flow
 
 from ..core import BaseDataGenusProcessor
+from ..config.log import logger
 from .load import LoaderDGP, PostLoaderDGP
 from .transform import TransformDGP
 from .enrich import EnricherDGP
@@ -21,10 +22,12 @@ class SimpleDGP(BaseDataGenusProcessor):
     def flow(self):
         flows = []
         for i, step in enumerate(self.steps):
+            logger.debug('Adding step %s to the flow', step.__class__.__name__)
             flow = step.flow()
             if flow:
                 flows.append(flow)
             else:
+                logger.debug('Step %s caused flow building to stop', step.__class__.__name__)
                 break
             flow = step.preflow()
             if flow:
